<h1 align="center"> Azur Lane Tool Lib </h1>
<h4 align="center">Tools lib for Azur Lane which game powered by ManJiu Shanghai.
Accelerating library iteration.</h4>
<p  align="center">
<a href="https://pypi.org/manage/project/AzurLaneToolLib/release/0.6.2/"><img src="https://img.shields.io/pypi/v/azurlanetoollib"></a>
<a href="https://www.gnu.org/licenses/quick-guide-gplv3.zh-cn.html"><img src="https://img.shields.io/pypi/l/azurlanetoollib?color=green"></a>
<img src="https://img.shields.io/pypi/dd/azurlanetoollib?color=yellow">
</p>
<hr />

# Open Source Download Link

## Relase From Pypi

https://pypi.org/manage/project/azurlanetoollib/releases/

# Information

Accelerating library iteration.

## Proper nouns

**Kinetics Artifactual Navy Self-fegulative En-lore Node**
-> ***KANSEN*** -> ***舰船（艦船）***

動力学人工海上作戦機構·自律行動型伝承接続端子 -> 艦船(*KanSen*)

动力学人工海上作战机构·自律行动型历史连接节点 -> 舰船(*KanSen*)

# Copyright Information

## LICENSE

> Copyright (C) 2019 - 2023 Matt Belfast Brown
>
> This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
> License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
> version.
>
> This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
> warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
>
> You should have received a copy of the GNU General Public License along with this program. If not,
> see <https://www.gnu.org/licenses/> .

## Author

### Author Information

> Author: ***Matt Belfast Brown*** or *Matt Brown* or *M.B.B.*（ **Name in English** ）
>> Also be called ***The Day of The Doctor*** ( **Network Nickname** )  
> > ***鈴木夢美*** or ***伊藤京介*** ( **Name in Japanese** )  
> > ***沈永基***，***皓月***，***飞瀑山人***，***衍枫阁主人*** ( **Name in Chinese, Style Name, Pseudonym, Alias** )

### Contact Details

> E-mail: ***thedayofthedo@gmail.com*** or ***thedayofthedoctor@foxmail.com***   
> TEL: ___+86-15841486187___
>
> Address: **Room 313, Apartment No. 14, South District, South Campus, Northwest A&F University, No. 22, Xinong Road,
Litai Street, Yangling District, Shaanxi Province, China**  
> Address: ***中国陕西省杨凌区李台街道西农路22号西北农林科技大学南校区南区14号公寓313宿舍***

## Update Log

### Version:

   ***now**

| Release Version |    Status     |  Release Data  | Update Info                                  | 
|----------------:|:-------------:|:--------------:|:---------------------------------------------|
|       **0.6.3** | **available** | **2023-03-08** | **Write documents and Improve information.** |
|           0.6.2 |   available   |   2023-03-05   | Fixed some errors.                           |
|           0.6.1 |   available   |   2023-03-05   | Add mode `mode_SRS_Ptl.py`                   |
|           0.6.0 |   available   |   2022-10-20   | Re planned version number                    |                                     |
|         0.5.3.1 |   available   |   2022-09-13   | Update new kansen name.                      |
|           0.5.3 |   available   |   2022-03-27   | Add and correct all comments.                |
|           0.5.2 |   available   |   2022-03-26   | Full mode for FCS_Cal.                       |
|           0.5.1 |   available   |   2022-02-22   | New mode and new algorithm.                  |
|         0.5.1α2 |   available   |   2022-02-18   | Test for 0.5.1 and new md.                   |

**First Edition Time: 2019-07-11**  
**Last Revision Time: 2023-03-08**  
**Version Number: 0.6.3**  
**ReadMe.md Version: 0.6.3**

> **Version Update Log:**
>
>> #### 0.6.3
>> + 补充自述文件
>> + 完善信息
>
>> #### 0.6.2
>> + 修正了部分错误
>
>> #### 0.6.1
>> + 完成数据核验
>> + 完成模块`mode_SRS_Ptl.py`
>> + 修正了部分错误
>
>> #### 0.6.0
>> + 重新规划了版本号
>> + 重新修订了舰船数据
>> + 新增数据文件`data_AZR_Lan.py`
>> + 删除原数据`data_FLE_Shi.py`
>> + 新增未完成模块`mode_SRS_Ptl.py`
>
>> #### 0.5.3.1
>> + 添加了新舰船和谐名
>
>> #### 0.5.3
>> + 添加并完善了注释结构
>> + 修正了部分错误
>
>> #### 0.5.2
>> - 完整完成模块`mode_FCS_Cal.py`
>> - 修订了部分注释
>
>> #### 0.5.1
>> + 更新ReadME文档
>> + 使用PyCharm进行代码体系更新
>> + 从AzurLaneFleetTool(**author: x94fujo6rpg**)改编新增`mode_FLE_Tol.py`
>
>> #### 0.5.1α2
>> + 从 Azur Lane Fleet  (**author: x94fujo6rpg**)中提取并添加新模块
>> + 重写文件 `setup.py`.
>> + 尝试添加文档